
#include <vector>

namespace zeek
	{
class RE_Matcher;
	}

namespace binpac
	{

std::vector<zeek::RE_Matcher*>* uncompiled_re_matchers = nullptr;

	}
